Learn R Programming

crmn (version 0.0.22)

analytes: Accessor for the analytes

Description

Subset an data set to only contain the analytes.

Usage

analytes(object, standards=NULL, ...)

Value

subsetted dataset

Arguments

object

an ExpressionSet, matrix or data.frame

standards

a logical vector indicating which rows are internal analytes

...

not used

Author

Henning Redestig

Examples

Run this code
data(mix)
analytes(mix)
analytes(exprs(mix), fData(mix)$tag == 'IS')

Run the code above in your browser using DataLab