Learn R Programming

crmn (version 0.0.22)

analytes_other: Accessor for the analytes

Description

Subset an expression set to remove the internal standards

Usage

analytes_other(object, standards, ...)

Value

ExpressionSet

Arguments

object

an ExpressionSet

standards

a logical vector indicating which rows are internal standards

...

not used

Author

Henning Redestig

Examples

Run this code
data(mix)
analytes(exprs(mix), fData(mix)$tag == 'IS')

Run the code above in your browser using DataLab