Learn R Programming

crmn (version 0.0.22)

standards: Accessor for the Internal Standards

Description

Subset an data set to only contain the labeled internal standards.

Usage

standards(object, standards=NULL, ...)

Value

subsetted dataset

Arguments

object

an ExpressionSet, matrix or data.frame

standards

a logical vector indicating which rows are internal standards

...

not used

Author

Henning Redestig

Examples

Run this code
data(mix)
standards(mix)
standards(exprs(mix), fData(mix)$tag == 'IS')

Run the code above in your browser using DataLab