powered by
Subset an data set to only contain the labeled internal standards.
standards_other(object, standards, ...)
subsetted dataset
an matrix or data.frame
matrix
data.frame
a logical vector indicating which rows are internal standards
not used
Henning Redestig
data(mix) standards(exprs(mix), fData(mix)$tag == 'IS')
Run the code above in your browser using DataLab