powered by
Subset an data set to only contain the analytes.
analytes(object, standards=NULL, ...)
subsetted dataset
an ExpressionSet, matrix or data.frame
ExpressionSet
matrix
data.frame
a logical vector indicating which rows are internal analytes
not used
Henning Redestig
data(mix) analytes(mix) analytes(exprs(mix), fData(mix)$tag == 'IS')
Run the code above in your browser using DataLab