powered by
Subset an expression set to remove the internal standards
analytes_other(object, standards, ...)
ExpressionSet
an ExpressionSet
a logical vector indicating which rows are internal standards
not used
Henning Redestig
data(mix) analytes(exprs(mix), fData(mix)$tag == 'IS')
Run the code above in your browser using DataLab